richimage
open | /manage_main |
selectAndWait | :action | label=Plone Site
type | siteid | Site
addSelection | extension_ids | label=RichImage
clickAndWait | submit |
clickAndWait | link=Site (Site) |
clickAndWait | //td[3]/font/a/span/strong |
click | //dl[@id='plone-contentmenu-factories']/dt/a/span[1] |
clickAndWait | richimage |
type | title | Image 1
type | image_file | /tmp/img.jpg
clickAndWait | form_submit |
clickAndWait | link=Edit |
click | //a[@id='fieldsetlegend-crops']/span |
clickAndWait | //img[@title='Edit'] |
click | //body/div[5] |
clickAndWait | recrop |
click | //a[@id='fieldsetlegend-crops']/span |
open | /manage_main |
click | //input[@name='ids:list' and @value='Site'] |
click | manage_delObjects:method |